-- main.lua for bezier.love

function love.load()

	gr = love.graphics
	gr.setCaption( "Bezier Curve Fit" )
	x = { 100, 100, 700, 700 }
	y = { 500, 100, 100, 500 }
	gr.setBackgroundColor( 155, 155,195, 255 )
	gr.setFont( gr.newFont( 18 ) )

	end

function love.draw()

	gr.setColor(0, 0, 50, 80)
	for i = 1, #x - 1 do gr.line( x[i], y[i], x[i+1], y[i+1] ) end

	gr.setColor( 0, 0, 50, 255 )
	for i=1,#x do circle( x[i], y[i], 8 ) end

	gr.setColor( 255, 0, 0, 255 )
	data = Bezier( x, y, 0.01)
	for i = 1, #data - 1 do
		gr.line( data[i][1], data[i][2], data[i+1][1], data[i+1][2] )
		end

	gr.setColor(255, 255, 0, 255)
	gr.print("FPS: " .. love.timer.getFPS(), 10, 10)
	text = "X1 Y1: "..x[1].." - "..y[1].."\nX2 Y2: "..x[2].." - "..y[2].."\nX3 Y3: "..x[3].." - "..y[3].."\nX4 Y4: "..x[4].." - "..y[4]
	gr.print(text,10,510)

	end

function love.mousepressed(mx, my, button)

	if button == "l" then
		d = {}
		for i = 1, 4 do d[i] = math.sqrt( (x[i]-mx)^2 + (y[i]-my)^2) end
		min_val = math.min( d[1], math.min( d[2], math.min( d[3], d[4] ) ) )
		for i = 1,#d do if d[i] == min_val then x[i] = mx y[i] = my end end
		end

	end

function love.keypressed( key )

	if key == "escape" then love.event.quit() end

	end

function circle( cx, cy, r ) gr.circle( 'line', cx, cy, r, r ) end

function Bezier(px,py,steps)

	local bezier = {} index = 0      -- bezier is a table of xy pairs
	local cx = 3 * ( px[ 2 ] - px[ 1 ] )
	local cy = 3 * ( py[ 2 ] - py[ 1 ] )
	local bx = 3 * ( px[ 3 ] - px[ 2 ]) - cx
	local by = 3 * ( py[ 3 ] - py[ 2 ]) - cy
	local ax = px[ 4 ] - px[ 1 ] - cx - bx
	local ay = py[ 4 ] - py[ 1 ] - cy - by
	index = index + 1
	bezier[index]={px[1],py[1]}
	for t = 0, 1, steps do  -- steps typically equals .01
		local X = ax * t^3 + bx * t^2 + cx * t + px[ 1 ]
		local Y = ay * t^3 + by * t^2 + cy * t + py[ 1 ]
		index = index + 1
		bezier[ index ] = { X, Y }
		end
	return bezier

	end


